@@ -55,6 +55,7 @@
 #include <QtGui/qvector4d.h>
 #include <QtGui/qrasterwindow.h>
 #include <QtGui/qscreen.h>
+#include <QtGui/qopenglpaintdevice.h>
 #include <QtGui/qicon.h>
 #include <QTextBlock>
 #include <QtGui/qmovie.h>
@@ -231,7 +232,7 @@ enum : int {
     SBK_QFOCUSEVENT_IDX                                      = 81,
     SBK_QFONT_STYLEHINT_IDX                                  = 87,
     SBK_QFONT_STYLESTRATEGY_IDX                              = 88,
-    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 379,
+    SBK_QFONT_HINTINGPREFERENCE_IDX                          = 380,
     SBK_QFONT_WEIGHT_IDX                                     = 89,
     SBK_QFONT_STYLE_IDX                                      = 86,
     SBK_QFONT_STRETCH_IDX                                    = 85,
@@ -337,229 +338,230 @@ enum : int {
     SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX                   = 174,
     SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX            = 65,
     SBK_QOPENGLFUNCTIONS_IDX                                 = 173,
-    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 175,
-    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 177,
+    SBK_QOPENGLPAINTDEVICE_IDX                               = 175,
+    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 176,
+    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 178,
     SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX               = 66,
-    SBK_QOPENGLSHADER_IDX                                    = 176,
-    SBK_QOPENGLSHADERPROGRAM_IDX                             = 178,
-    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 193,
-    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 180,
-    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 188,
-    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 196,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 194,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 195,
-    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 184,
-    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 189,
-    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 190,
-    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 191,
-    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 192,
-    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 197,
-    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 183,
-    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 186,
+    SBK_QOPENGLSHADER_IDX                                    = 177,
+    SBK_QOPENGLSHADERPROGRAM_IDX                             = 179,
+    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 194,
+    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 181,
+    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 189,
+    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 197,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 195,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 196,
+    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 185,
+    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 190,
+    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 191,
+    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 192,
+    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 193,
+    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 198,
+    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 184,
+    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 187,
     SBK_QFLAGS_QOPENGLTEXTURE_FEATURE_IDX                    = 67,
-    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 185,
-    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 181,
-    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 182,
-    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 187,
-    SBK_QOPENGLTEXTURE_IDX                                   = 179,
-    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 199,
-    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 198,
-    SBK_QOPENGLTIMEMONITOR_IDX                               = 200,
-    SBK_QOPENGLTIMERQUERY_IDX                                = 201,
-    SBK_QOPENGLVERSIONPROFILE_IDX                            = 202,
-    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 203,
-    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 204,
-    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 206,
-    SBK_QOPENGLWINDOW_IDX                                    = 205,
-    SBK_QPAGELAYOUT_UNIT_IDX                                 = 210,
-    SBK_QPAGELAYOUT_ORIENTATION_IDX                          = 209,
-    SBK_QPAGELAYOUT_MODE_IDX                                 = 208,
-    SBK_QPAGELAYOUT_IDX                                      = 207,
-    SBK_QPAGESIZE_PAGESIZEID_IDX                             = 212,
-    SBK_QPAGESIZE_UNIT_IDX                                   = 214,
-    SBK_QPAGESIZE_SIZEMATCHPOLICY_IDX                        = 213,
-    SBK_QPAGESIZE_IDX                                        = 211,
-    SBK_QPAGEDPAINTDEVICE_PAGESIZE_IDX                       = 217,
-    SBK_QPAGEDPAINTDEVICE_PDFVERSION_IDX                     = 218,
-    SBK_QPAGEDPAINTDEVICE_IDX                                = 215,
-    SBK_QPAGEDPAINTDEVICE_MARGINS_IDX                        = 216,
-    SBK_QPAINTDEVICE_PAINTDEVICEMETRIC_IDX                   = 220,
-    SBK_QPAINTDEVICE_IDX                                     = 219,
-    SBK_QPAINTDEVICEWINDOW_IDX                               = 221,
-    SBK_QPAINTENGINE_PAINTENGINEFEATURE_IDX                  = 224,
+    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 186,
+    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 182,
+    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 183,
+    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 188,
+    SBK_QOPENGLTEXTURE_IDX                                   = 180,
+    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 200,
+    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 199,
+    SBK_QOPENGLTIMEMONITOR_IDX                               = 201,
+    SBK_QOPENGLTIMERQUERY_IDX                                = 202,
+    SBK_QOPENGLVERSIONPROFILE_IDX                            = 203,
+    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 204,
+    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 205,
+    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 207,
+    SBK_QOPENGLWINDOW_IDX                                    = 206,
+    SBK_QPAGELAYOUT_UNIT_IDX                                 = 211,
+    SBK_QPAGELAYOUT_ORIENTATION_IDX                          = 210,
+    SBK_QPAGELAYOUT_MODE_IDX                                 = 209,
+    SBK_QPAGELAYOUT_IDX                                      = 208,
+    SBK_QPAGESIZE_PAGESIZEID_IDX                             = 213,
+    SBK_QPAGESIZE_UNIT_IDX                                   = 215,
+    SBK_QPAGESIZE_SIZEMATCHPOLICY_IDX                        = 214,
+    SBK_QPAGESIZE_IDX                                        = 212,
+    SBK_QPAGEDPAINTDEVICE_PAGESIZE_IDX                       = 218,
+    SBK_QPAGEDPAINTDEVICE_PDFVERSION_IDX                     = 219,
+    SBK_QPAGEDPAINTDEVICE_IDX                                = 216,
+    SBK_QPAGEDPAINTDEVICE_MARGINS_IDX                        = 217,
+    SBK_QPAINTDEVICE_PAINTDEVICEMETRIC_IDX                   = 221,
+    SBK_QPAINTDEVICE_IDX                                     = 220,
+    SBK_QPAINTDEVICEWINDOW_IDX                               = 222,
+    SBK_QPAINTENGINE_PAINTENGINEFEATURE_IDX                  = 225,
     SBK_QFLAGS_QPAINTENGINE_PAINTENGINEFEATURE_IDX           = 69,
-    SBK_QPAINTENGINE_DIRTYFLAG_IDX                           = 223,
+    SBK_QPAINTENGINE_DIRTYFLAG_IDX                           = 224,
     SBK_QFLAGS_QPAINTENGINE_DIRTYFLAG_IDX                    = 68,
-    SBK_QPAINTENGINE_POLYGONDRAWMODE_IDX                     = 225,
-    SBK_QPAINTENGINE_TYPE_IDX                                = 226,
-    SBK_QPAINTENGINE_IDX                                     = 222,
-    SBK_QPAINTENGINESTATE_IDX                                = 227,
-    SBK_QPAINTEVENT_IDX                                      = 228,
-    SBK_QPAINTER_RENDERHINT_IDX                              = 233,
+    SBK_QPAINTENGINE_POLYGONDRAWMODE_IDX                     = 226,
+    SBK_QPAINTENGINE_TYPE_IDX                                = 227,
+    SBK_QPAINTENGINE_IDX                                     = 223,
+    SBK_QPAINTENGINESTATE_IDX                                = 228,
+    SBK_QPAINTEVENT_IDX                                      = 229,
+    SBK_QPAINTER_RENDERHINT_IDX                              = 234,
     SBK_QFLAGS_QPAINTER_RENDERHINT_IDX                       = 71,
-    SBK_QPAINTER_PIXMAPFRAGMENTHINT_IDX                      = 232,
+    SBK_QPAINTER_PIXMAPFRAGMENTHINT_IDX                      = 233,
     SBK_QFLAGS_QPAINTER_PIXMAPFRAGMENTHINT_IDX               = 70,
-    SBK_QPAINTER_COMPOSITIONMODE_IDX                         = 230,
-    SBK_QPAINTER_IDX                                         = 229,
-    SBK_QPAINTER_PIXMAPFRAGMENT_IDX                          = 231,
-    SBK_QPAINTERPATH_ELEMENTTYPE_IDX                         = 236,
-    SBK_QPAINTERPATH_IDX                                     = 234,
-    SBK_QPAINTERPATH_ELEMENT_IDX                             = 235,
-    SBK_QPAINTERPATHSTROKER_IDX                              = 237,
-    SBK_QPALETTE_COLORGROUP_IDX                              = 239,
-    SBK_QPALETTE_COLORROLE_IDX                               = 240,
-    SBK_QPALETTE_IDX                                         = 238,
-    SBK_QPDFWRITER_IDX                                       = 241,
-    SBK_QPEN_IDX                                             = 242,
-    SBK_QPICTURE_IDX                                         = 243,
-    SBK_QPICTUREIO_IDX                                       = 244,
-    SBK_QPIXELFORMAT_COLORMODEL_IDX                          = 250,
-    SBK_QPIXELFORMAT_ALPHAUSAGE_IDX                          = 248,
-    SBK_QPIXELFORMAT_ALPHAPOSITION_IDX                       = 246,
-    SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX                  = 247,
-    SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX                  = 251,
-    SBK_QPIXELFORMAT_YUVLAYOUT_IDX                           = 252,
-    SBK_QPIXELFORMAT_BYTEORDER_IDX                           = 249,
-    SBK_QPIXELFORMAT_IDX                                     = 245,
-    SBK_QPIXMAP_IDX                                          = 253,
-    SBK_QPIXMAPCACHE_IDX                                     = 254,
-    SBK_QPIXMAPCACHE_KEY_IDX                                 = 255,
-    SBK_QPOINTINGDEVICEUNIQUEID_IDX                          = 256,
-    SBK_QPOLYGON_IDX                                         = 257,
-    SBK_QVECTOR_QPOINT_IDX                                   = 257,
-    SBK_QPOLYGONF_IDX                                        = 258,
-    SBK_QVECTOR_QPOINTF_IDX                                  = 258,
-    SBK_QPYTEXTOBJECT_IDX                                    = 259,
-    SBK_QQUATERNION_IDX                                      = 260,
-    SBK_QRADIALGRADIENT_IDX                                  = 261,
-    SBK_QRASTERWINDOW_IDX                                    = 262,
-    SBK_QRAWFONT_ANTIALIASINGTYPE_IDX                        = 264,
-    SBK_QRAWFONT_LAYOUTFLAG_IDX                              = 265,
+    SBK_QPAINTER_COMPOSITIONMODE_IDX                         = 231,
+    SBK_QPAINTER_IDX                                         = 230,
+    SBK_QPAINTER_PIXMAPFRAGMENT_IDX                          = 232,
+    SBK_QPAINTERPATH_ELEMENTTYPE_IDX                         = 237,
+    SBK_QPAINTERPATH_IDX                                     = 235,
+    SBK_QPAINTERPATH_ELEMENT_IDX                             = 236,
+    SBK_QPAINTERPATHSTROKER_IDX                              = 238,
+    SBK_QPALETTE_COLORGROUP_IDX                              = 240,
+    SBK_QPALETTE_COLORROLE_IDX                               = 241,
+    SBK_QPALETTE_IDX                                         = 239,
+    SBK_QPDFWRITER_IDX                                       = 242,
+    SBK_QPEN_IDX                                             = 243,
+    SBK_QPICTURE_IDX                                         = 244,
+    SBK_QPICTUREIO_IDX                                       = 245,
+    SBK_QPIXELFORMAT_COLORMODEL_IDX                          = 251,
+    SBK_QPIXELFORMAT_ALPHAUSAGE_IDX                          = 249,
+    SBK_QPIXELFORMAT_ALPHAPOSITION_IDX                       = 247,
+    SBK_QPIXELFORMAT_ALPHAPREMULTIPLIED_IDX                  = 248,
+    SBK_QPIXELFORMAT_TYPEINTERPRETATION_IDX                  = 252,
+    SBK_QPIXELFORMAT_YUVLAYOUT_IDX                           = 253,
+    SBK_QPIXELFORMAT_BYTEORDER_IDX                           = 250,
+    SBK_QPIXELFORMAT_IDX                                     = 246,
+    SBK_QPIXMAP_IDX                                          = 254,
+    SBK_QPIXMAPCACHE_IDX                                     = 255,
+    SBK_QPIXMAPCACHE_KEY_IDX                                 = 256,
+    SBK_QPOINTINGDEVICEUNIQUEID_IDX                          = 257,
+    SBK_QPOLYGON_IDX                                         = 258,
+    SBK_QVECTOR_QPOINT_IDX                                   = 258,
+    SBK_QPOLYGONF_IDX                                        = 259,
+    SBK_QVECTOR_QPOINTF_IDX                                  = 259,
+    SBK_QPYTEXTOBJECT_IDX                                    = 260,
+    SBK_QQUATERNION_IDX                                      = 261,
+    SBK_QRADIALGRADIENT_IDX                                  = 262,
+    SBK_QRASTERWINDOW_IDX                                    = 263,
+    SBK_QRAWFONT_ANTIALIASINGTYPE_IDX                        = 265,
+    SBK_QRAWFONT_LAYOUTFLAG_IDX                              = 266,
     SBK_QFLAGS_QRAWFONT_LAYOUTFLAG_IDX                       = 72,
-    SBK_QRAWFONT_IDX                                         = 263,
-    SBK_QREGEXPVALIDATOR_IDX                                 = 266,
-    SBK_QREGION_REGIONTYPE_IDX                               = 268,
-    SBK_QREGION_IDX                                          = 267,
-    SBK_QREGULAREXPRESSIONVALIDATOR_IDX                      = 269,
-    SBK_QRESIZEEVENT_IDX                                     = 270,
-    SBK_QSCREEN_IDX                                          = 271,
-    SBK_QSCROLLEVENT_SCROLLSTATE_IDX                         = 273,
-    SBK_QSCROLLEVENT_IDX                                     = 272,
-    SBK_QSCROLLPREPAREEVENT_IDX                              = 274,
-    SBK_QSESSIONMANAGER_RESTARTHINT_IDX                      = 276,
-    SBK_QSESSIONMANAGER_IDX                                  = 275,
-    SBK_QSHORTCUTEVENT_IDX                                   = 277,
-    SBK_QSHOWEVENT_IDX                                       = 278,
-    SBK_QSTANDARDITEM_ITEMTYPE_IDX                           = 280,
-    SBK_QSTANDARDITEM_IDX                                    = 279,
-    SBK_QSTANDARDITEMMODEL_IDX                               = 281,
-    SBK_QSTATICTEXT_PERFORMANCEHINT_IDX                      = 283,
-    SBK_QSTATICTEXT_IDX                                      = 282,
-    SBK_QSTATUSTIPEVENT_IDX                                  = 284,
-    SBK_QSTYLEHINTS_IDX                                      = 285,
-    SBK_QSURFACE_SURFACECLASS_IDX                            = 287,
-    SBK_QSURFACE_SURFACETYPE_IDX                             = 288,
-    SBK_QSURFACE_IDX                                         = 286,
-    SBK_QSURFACEFORMAT_FORMATOPTION_IDX                      = 291,
+    SBK_QRAWFONT_IDX                                         = 264,
+    SBK_QREGEXPVALIDATOR_IDX                                 = 267,
+    SBK_QREGION_REGIONTYPE_IDX                               = 269,
+    SBK_QREGION_IDX                                          = 268,
+    SBK_QREGULAREXPRESSIONVALIDATOR_IDX                      = 270,
+    SBK_QRESIZEEVENT_IDX                                     = 271,
+    SBK_QSCREEN_IDX                                          = 272,
+    SBK_QSCROLLEVENT_SCROLLSTATE_IDX                         = 274,
+    SBK_QSCROLLEVENT_IDX                                     = 273,
+    SBK_QSCROLLPREPAREEVENT_IDX                              = 275,
+    SBK_QSESSIONMANAGER_RESTARTHINT_IDX                      = 277,
+    SBK_QSESSIONMANAGER_IDX                                  = 276,
+    SBK_QSHORTCUTEVENT_IDX                                   = 278,
+    SBK_QSHOWEVENT_IDX                                       = 279,
+    SBK_QSTANDARDITEM_ITEMTYPE_IDX                           = 281,
+    SBK_QSTANDARDITEM_IDX                                    = 280,
+    SBK_QSTANDARDITEMMODEL_IDX                               = 282,
+    SBK_QSTATICTEXT_PERFORMANCEHINT_IDX                      = 284,
+    SBK_QSTATICTEXT_IDX                                      = 283,
+    SBK_QSTATUSTIPEVENT_IDX                                  = 285,
+    SBK_QSTYLEHINTS_IDX                                      = 286,
+    SBK_QSURFACE_SURFACECLASS_IDX                            = 288,
+    SBK_QSURFACE_SURFACETYPE_IDX                             = 289,
+    SBK_QSURFACE_IDX                                         = 287,
+    SBK_QSURFACEFORMAT_FORMATOPTION_IDX                      = 292,
     SBK_QFLAGS_QSURFACEFORMAT_FORMATOPTION_IDX               = 73,
-    SBK_QSURFACEFORMAT_SWAPBEHAVIOR_IDX                      = 294,
-    SBK_QSURFACEFORMAT_RENDERABLETYPE_IDX                    = 293,
-    SBK_QSURFACEFORMAT_OPENGLCONTEXTPROFILE_IDX              = 292,
-    SBK_QSURFACEFORMAT_COLORSPACE_IDX                        = 290,
-    SBK_QSURFACEFORMAT_IDX                                   = 289,
-    SBK_QSYNTAXHIGHLIGHTER_IDX                               = 295,
-    SBK_QTABLETEVENT_TABLETDEVICE_IDX                        = 298,
-    SBK_QTABLETEVENT_POINTERTYPE_IDX                         = 297,
-    SBK_QTABLETEVENT_IDX                                     = 296,
-    SBK_QTEXTBLOCK_IDX                                       = 299,
-    SBK_QTEXTBLOCK_ITERATOR_IDX                              = 300,
-    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 380,
-    SBK_QTEXTBLOCKFORMAT_MARKERTYPE_IDX                      = 302,
-    SBK_QTEXTBLOCKFORMAT_IDX                                 = 301,
-    SBK_QTEXTBLOCKGROUP_IDX                                  = 303,
-    SBK_QTEXTBLOCKUSERDATA_IDX                               = 304,
-    SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX                = 308,
-    SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX                   = 307,
-    SBK_QTEXTCHARFORMAT_FONTPROPERTIESINHERITANCEBEHAVIOR_IDX = 306,
-    SBK_QTEXTCHARFORMAT_IDX                                  = 305,
-    SBK_QTEXTCURSOR_MOVEMODE_IDX                             = 310,
-    SBK_QTEXTCURSOR_MOVEOPERATION_IDX                        = 311,
-    SBK_QTEXTCURSOR_SELECTIONTYPE_IDX                        = 312,
-    SBK_QTEXTCURSOR_IDX                                      = 309,
-    SBK_QTEXTDOCUMENT_METAINFORMATION_IDX                    = 316,
-    SBK_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX                    = 315,
+    SBK_QSURFACEFORMAT_SWAPBEHAVIOR_IDX                      = 295,
+    SBK_QSURFACEFORMAT_RENDERABLETYPE_IDX                    = 294,
+    SBK_QSURFACEFORMAT_OPENGLCONTEXTPROFILE_IDX              = 293,
+    SBK_QSURFACEFORMAT_COLORSPACE_IDX                        = 291,
+    SBK_QSURFACEFORMAT_IDX                                   = 290,
+    SBK_QSYNTAXHIGHLIGHTER_IDX                               = 296,
+    SBK_QTABLETEVENT_TABLETDEVICE_IDX                        = 299,
+    SBK_QTABLETEVENT_POINTERTYPE_IDX                         = 298,
+    SBK_QTABLETEVENT_IDX                                     = 297,
+    SBK_QTEXTBLOCK_IDX                                       = 300,
+    SBK_QTEXTBLOCK_ITERATOR_IDX                              = 301,
+    SBK_QTEXTBLOCKFORMAT_LINEHEIGHTTYPES_IDX                 = 381,
+    SBK_QTEXTBLOCKFORMAT_MARKERTYPE_IDX                      = 303,
+    SBK_QTEXTBLOCKFORMAT_IDX                                 = 302,
+    SBK_QTEXTBLOCKGROUP_IDX                                  = 304,
+    SBK_QTEXTBLOCKUSERDATA_IDX                               = 305,
+    SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX                = 309,
+    SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX                   = 308,
+    SBK_QTEXTCHARFORMAT_FONTPROPERTIESINHERITANCEBEHAVIOR_IDX = 307,
+    SBK_QTEXTCHARFORMAT_IDX                                  = 306,
+    SBK_QTEXTCURSOR_MOVEMODE_IDX                             = 311,
+    SBK_QTEXTCURSOR_MOVEOPERATION_IDX                        = 312,
+    SBK_QTEXTCURSOR_SELECTIONTYPE_IDX                        = 313,
+    SBK_QTEXTCURSOR_IDX                                      = 310,
+    SBK_QTEXTDOCUMENT_METAINFORMATION_IDX                    = 317,
+    SBK_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX                    = 316,
     SBK_QFLAGS_QTEXTDOCUMENT_MARKDOWNFEATURE_IDX             = 75,
-    SBK_QTEXTDOCUMENT_FINDFLAG_IDX                           = 314,
+    SBK_QTEXTDOCUMENT_FINDFLAG_IDX                           = 315,
     SBK_QFLAGS_QTEXTDOCUMENT_FINDFLAG_IDX                    = 74,
-    SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX                       = 317,
-    SBK_QTEXTDOCUMENT_STACKS_IDX                             = 318,
-    SBK_QTEXTDOCUMENT_IDX                                    = 313,
-    SBK_QTEXTDOCUMENTFRAGMENT_IDX                            = 319,
-    SBK_QTEXTDOCUMENTWRITER_IDX                              = 320,
-    SBK_QTEXTFORMAT_FORMATTYPE_IDX                           = 322,
-    SBK_QTEXTFORMAT_PROPERTY_IDX                             = 325,
-    SBK_QTEXTFORMAT_OBJECTTYPES_IDX                          = 323,
-    SBK_QTEXTFORMAT_PAGEBREAKFLAG_IDX                        = 324,
+    SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX                       = 318,
+    SBK_QTEXTDOCUMENT_STACKS_IDX                             = 319,
+    SBK_QTEXTDOCUMENT_IDX                                    = 314,
+    SBK_QTEXTDOCUMENTFRAGMENT_IDX                            = 320,
+    SBK_QTEXTDOCUMENTWRITER_IDX                              = 321,
+    SBK_QTEXTFORMAT_FORMATTYPE_IDX                           = 323,
+    SBK_QTEXTFORMAT_PROPERTY_IDX                             = 326,
+    SBK_QTEXTFORMAT_OBJECTTYPES_IDX                          = 324,
+    SBK_QTEXTFORMAT_PAGEBREAKFLAG_IDX                        = 325,
     SBK_QFLAGS_QTEXTFORMAT_PAGEBREAKFLAG_IDX                 = 76,
-    SBK_QTEXTFORMAT_IDX                                      = 321,
-    SBK_QTEXTFRAGMENT_IDX                                    = 326,
-    SBK_QTEXTFRAME_IDX                                       = 327,
-    SBK_QTEXTFRAME_ITERATOR_IDX                              = 328,
-    SBK_QTEXTFRAMEFORMAT_POSITION_IDX                        = 331,
-    SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX                     = 330,
-    SBK_QTEXTFRAMEFORMAT_IDX                                 = 329,
-    SBK_QTEXTIMAGEFORMAT_IDX                                 = 332,
-    SBK_QTEXTINLINEOBJECT_IDX                                = 333,
-    SBK_QTEXTITEM_RENDERFLAG_IDX                             = 335,
+    SBK_QTEXTFORMAT_IDX                                      = 322,
+    SBK_QTEXTFRAGMENT_IDX                                    = 327,
+    SBK_QTEXTFRAME_IDX                                       = 328,
+    SBK_QTEXTFRAME_ITERATOR_IDX                              = 329,
+    SBK_QTEXTFRAMEFORMAT_POSITION_IDX                        = 332,
+    SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX                     = 331,
+    SBK_QTEXTFRAMEFORMAT_IDX                                 = 330,
+    SBK_QTEXTIMAGEFORMAT_IDX                                 = 333,
+    SBK_QTEXTINLINEOBJECT_IDX                                = 334,
+    SBK_QTEXTITEM_RENDERFLAG_IDX                             = 336,
     SBK_QFLAGS_QTEXTITEM_RENDERFLAG_IDX                      = 77,
-    SBK_QTEXTITEM_IDX                                        = 334,
-    SBK_QTEXTLAYOUT_CURSORMODE_IDX                           = 337,
-    SBK_QTEXTLAYOUT_IDX                                      = 336,
-    SBK_QTEXTLAYOUT_FORMATRANGE_IDX                          = 338,
-    SBK_QTEXTLENGTH_TYPE_IDX                                 = 340,
-    SBK_QTEXTLENGTH_IDX                                      = 339,
-    SBK_QTEXTLINE_EDGE_IDX                                   = 343,
-    SBK_QTEXTLINE_CURSORPOSITION_IDX                         = 342,
-    SBK_QTEXTLINE_IDX                                        = 341,
-    SBK_QTEXTLIST_IDX                                        = 344,
-    SBK_QTEXTLISTFORMAT_STYLE_IDX                            = 346,
-    SBK_QTEXTLISTFORMAT_IDX                                  = 345,
-    SBK_QTEXTOBJECT_IDX                                      = 347,
-    SBK_QTEXTOBJECTINTERFACE_IDX                             = 348,
-    SBK_QTEXTOPTION_TABTYPE_IDX                              = 352,
-    SBK_QTEXTOPTION_WRAPMODE_IDX                             = 353,
-    SBK_QTEXTOPTION_FLAG_IDX                                 = 350,
+    SBK_QTEXTITEM_IDX                                        = 335,
+    SBK_QTEXTLAYOUT_CURSORMODE_IDX                           = 338,
+    SBK_QTEXTLAYOUT_IDX                                      = 337,
+    SBK_QTEXTLAYOUT_FORMATRANGE_IDX                          = 339,
+    SBK_QTEXTLENGTH_TYPE_IDX                                 = 341,
+    SBK_QTEXTLENGTH_IDX                                      = 340,
+    SBK_QTEXTLINE_EDGE_IDX                                   = 344,
+    SBK_QTEXTLINE_CURSORPOSITION_IDX                         = 343,
+    SBK_QTEXTLINE_IDX                                        = 342,
+    SBK_QTEXTLIST_IDX                                        = 345,
+    SBK_QTEXTLISTFORMAT_STYLE_IDX                            = 347,
+    SBK_QTEXTLISTFORMAT_IDX                                  = 346,
+    SBK_QTEXTOBJECT_IDX                                      = 348,
+    SBK_QTEXTOBJECTINTERFACE_IDX                             = 349,
+    SBK_QTEXTOPTION_TABTYPE_IDX                              = 353,
+    SBK_QTEXTOPTION_WRAPMODE_IDX                             = 354,
+    SBK_QTEXTOPTION_FLAG_IDX                                 = 351,
     SBK_QFLAGS_QTEXTOPTION_FLAG_IDX                          = 78,
-    SBK_QTEXTOPTION_IDX                                      = 349,
-    SBK_QTEXTOPTION_TAB_IDX                                  = 351,
-    SBK_QTEXTTABLE_IDX                                       = 354,
-    SBK_QTEXTTABLECELL_IDX                                   = 355,
-    SBK_QTEXTTABLECELLFORMAT_IDX                             = 356,
-    SBK_QTEXTTABLEFORMAT_IDX                                 = 357,
-    SBK_QTOOLBARCHANGEEVENT_IDX                              = 358,
-    SBK_QTOUCHDEVICE_DEVICETYPE_IDX                          = 361,
-    SBK_QTOUCHDEVICE_CAPABILITYFLAG_IDX                      = 360,
+    SBK_QTEXTOPTION_IDX                                      = 350,
+    SBK_QTEXTOPTION_TAB_IDX                                  = 352,
+    SBK_QTEXTTABLE_IDX                                       = 355,
+    SBK_QTEXTTABLECELL_IDX                                   = 356,
+    SBK_QTEXTTABLECELLFORMAT_IDX                             = 357,
+    SBK_QTEXTTABLEFORMAT_IDX                                 = 358,
+    SBK_QTOOLBARCHANGEEVENT_IDX                              = 359,
+    SBK_QTOUCHDEVICE_DEVICETYPE_IDX                          = 362,
+    SBK_QTOUCHDEVICE_CAPABILITYFLAG_IDX                      = 361,
     SBK_QFLAGS_QTOUCHDEVICE_CAPABILITYFLAG_IDX               = 79,
-    SBK_QTOUCHDEVICE_IDX                                     = 359,
-    SBK_QTOUCHEVENT_IDX                                      = 362,
-    SBK_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX                  = 364,
+    SBK_QTOUCHDEVICE_IDX                                     = 360,
+    SBK_QTOUCHEVENT_IDX                                      = 363,
+    SBK_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX                  = 365,
     SBK_QFLAGS_QTOUCHEVENT_TOUCHPOINT_INFOFLAG_IDX           = 80,
-    SBK_QTOUCHEVENT_TOUCHPOINT_IDX                           = 363,
-    SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX                    = 366,
-    SBK_QTRANSFORM_IDX                                       = 365,
-    SBK_QVALIDATOR_STATE_IDX                                 = 368,
-    SBK_QVALIDATOR_IDX                                       = 367,
-    SBK_QVECTOR2D_IDX                                        = 369,
-    SBK_QVECTOR3D_IDX                                        = 370,
-    SBK_QVECTOR4D_IDX                                        = 371,
-    SBK_QWHATSTHISCLICKEDEVENT_IDX                           = 372,
-    SBK_QWHEELEVENT_IDX                                      = 373,
-    SBK_QWINDOW_VISIBILITY_IDX                               = 376,
-    SBK_QWINDOW_ANCESTORMODE_IDX                             = 375,
-    SBK_QWINDOW_IDX                                          = 374,
-    SBK_QWINDOWSTATECHANGEEVENT_IDX                          = 377,
-    SBK_QtGuiQT_IDX                                          = 378,
-    SBK_QtGui_IDX_COUNT                                      = 381
+    SBK_QTOUCHEVENT_TOUCHPOINT_IDX                           = 364,
+    SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX                    = 367,
+    SBK_QTRANSFORM_IDX                                       = 366,
+    SBK_QVALIDATOR_STATE_IDX                                 = 369,
+    SBK_QVALIDATOR_IDX                                       = 368,
+    SBK_QVECTOR2D_IDX                                        = 370,
+    SBK_QVECTOR3D_IDX                                        = 371,
+    SBK_QVECTOR4D_IDX                                        = 372,
+    SBK_QWHATSTHISCLICKEDEVENT_IDX                           = 373,
+    SBK_QWHEELEVENT_IDX                                      = 374,
+    SBK_QWINDOW_VISIBILITY_IDX                               = 377,
+    SBK_QWINDOW_ANCESTORMODE_IDX                             = 376,
+    SBK_QWINDOW_IDX                                          = 375,
+    SBK_QWINDOWSTATECHANGEEVENT_IDX                          = 378,
+    SBK_QtGuiQT_IDX                                          = 379,
+    SBK_QtGui_IDX_COUNT                                      = 382
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtGuiTypes;
@@ -796,6 +798,7 @@ template<> inline PyTypeObject *SbkType< ::QOpenGLFramebufferObjectFormat >() {
 template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions::OpenGLFeature >() { return SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QOpenGLFunctions::OpenGLFeature> >() { return SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLFUNCTIONS_OPENGLFEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QOPENGLFUNCTIONS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLPaintDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QOPENGLPAINTDEVICE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLPixelTransferOptions >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtGuiTypes[SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLShader::ShaderTypeBit >() { return SbkPySide2_QtGuiTypes[SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QOpenGLShader::ShaderTypeBit> >() { return SbkPySide2_QtGuiTypes[SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
